@@ -7,16 +7,20 @@ from typing import (
     Any, Iterator, List, Optional, Union,
 )
 
+from amundsen_rds.models import RDSModel
+from amundsen_rds.models.dashboard import DashboardTable as RDSDashboardTable
+
 from databuilder.models.dashboard.dashboard_metadata import DashboardMetadata
 from databuilder.models.graph_node import GraphNode
 from databuilder.models.graph_relationship import GraphRelationship
 from databuilder.models.graph_serializable import GraphSerializable
 from databuilder.models.table_metadata import TableMetadata
+from databuilder.models.table_serializable import TableSerializable
 
 LOGGER = logging.getLogger(__name__)
 
 
-class DashboardTable(GraphSerializable):
+class DashboardTable(GraphSerializable, TableSerializable):
     """
     A model that link Dashboard with the tables used in various charts of the dashboard.
     Note that it does not create new dashboard, table as it has insufficient information but it builds relation
@@ -42,6 +46,7 @@ class DashboardTable(GraphSerializable):
         self._cluster = cluster
 
         self._relation_iterator = self._create_relation_iterator()
+        self._record_iterator = self._create_record_iterator()
 
     def create_next_node(self) -> Union[GraphNode, None]:
         return None
@@ -79,6 +84,31 @@ class DashboardTable(GraphSerializable):
                 )
                 yield relationship
 
+    def create_next_record(self) -> Union[RDSModel, None]:
+        try:
+            return next(self._record_iterator)
+        except StopIteration:
+            return None
+
+    def _create_record_iterator(self) -> Iterator[RDSModel]:
+        for table_id in self._table_ids:
+            m = re.match('([^./]+)://([^./]+)\.([^./]+)\/([^./]+)', table_id)
+            if m:
+                yield RDSDashboardTable(
+                    dashboard_rk=DashboardMetadata.DASHBOARD_KEY_FORMAT.format(
+                        product=self._product,
+                        cluster=self._cluster,
+                        dashboard_group=self._dashboard_group_id,
+                        dashboard_name=self._dashboard_id
+                    ),
+                    table_rk=TableMetadata.TABLE_KEY_FORMAT.format(
+                        db=m.group(1),
+                        cluster=m.group(2),
+                        schema=m.group(3),
+                        tbl=m.group(4)
+                    )
+                )
+
     def __repr__(self) -> str:
         return f'DashboardTable({self._dashboard_group_id!r}, {self._dashboard_id!r}, ' \
                f'{self._product!r}, {self._cluster!r}, ({",".join(self._table_ids)!r}))'
